#message types
"""
The message types that are supported by the package  are - 

- RAW
- PYOBJ
- JSON
- MULTIPART
- STRING
- UNICODE

This map to the same types supported by pyzmq
"""
RAW, PYOBJ, JSON, MULTIPART, STRING, UNICODE = range(6)
